agentle.agents.whatsapp.models.whatsapp\_text\_message
======================================================

.. automodule:: agentle.agents.whatsapp.models.whatsapp_text_message

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      Sequence
      WhatsAppMessage
      WhatsAppMessageType
      WhatsAppTextMessage
   